====================
django-oscar-reports
====================

|  |build| |coverage| |license| |kit| |format|

An extension on-top of django-oscar that improves the Oscar Dashboard's report generation system.

.. |build| image:: https://gitlab.com/thelabnyc/django-oscar/django-oscar-reports/badges/master/pipeline.svg
    :target: https://gitlab.com/thelabnyc/django-oscar/django-oscar-reports/commits/master
.. |coverage| image:: https://gitlab.com/thelabnyc/django-oscar/django-oscar-reports/badges/master/coverage.svg
    :target: https://gitlab.com/thelabnyc/django-oscar/django-oscar-reports/commits/master
.. |license| image:: https://img.shields.io/pypi/l/django-oscar-reports.svg
    :target: https://pypi.python.org/pypi/django-oscar-reports
.. |kit| image:: https://badge.fury.io/py/django-oscar-reports.svg
    :target: https://pypi.python.org/pypi/django-oscar-reports
.. |format| image:: https://img.shields.io/pypi/format/django-oscar-reports.svg
    :target: https://pypi.python.org/pypi/django-oscar-reports
